import { BigNumber, Contract, Event, providers } from "ethers";
import winston from "winston";
import { DepositWithBlock, V3FundsDepositedEvent, RealizedLpFee, RelayerRefundExecutionWithBlock, SlowFillRequestWithBlock, FillWithBlock, SlowFillLeaf, SpeedUp } from "../../interfaces";
import { SpokePoolClient, SpokePoolUpdate } from "../SpokePoolClient";
import { HubPoolClient } from "../HubPoolClient";
import { EventManager, EventOverrides } from "./MockEvents";
type Block = providers.Block;
export declare class MockSpokePoolClient extends SpokePoolClient {
    eventManager: EventManager;
    private realizedLpFeePct;
    private realizedLpFeePctOverride;
    private destinationTokenForChainOverride;
    depositIdAtBlock: number[];
    numberOfDeposits: number;
    blocks: Record<number, Block>;
    constructor(logger: winston.Logger, spokePool: Contract, chainId: number, deploymentBlock: number, opts?: {
        hubPoolClient: HubPoolClient | null;
    });
    setDefaultRealizedLpFeePct(fee: BigNumber): void;
    clearDefaultRealizedLpFeePct(): void;
    computeRealizedLpFeePct(depositEvent: V3FundsDepositedEvent): Promise<RealizedLpFee>;
    batchComputeRealizedLpFeePct(depositEvents: V3FundsDepositedEvent[]): Promise<RealizedLpFee[]>;
    setDestinationTokenForChain(chainId: number, token: string): void;
    getDestinationTokenForDeposit(deposit: DepositWithBlock): string;
    setLatestBlockNumber(blockNumber: number): void;
    setDepositIds(_depositIds: number[]): void;
    _getDepositIdAtBlock(blockTag: number): Promise<number>;
    _update(eventsToQuery: string[]): Promise<SpokePoolUpdate>;
    readonly eventSignatures: Record<string, string>;
    depositV3(deposit: DepositWithBlock): Event;
    fillV3Relay(fill: FillWithBlock): Event;
    speedUpV3Deposit(speedUp: SpeedUp): Event;
    requestV3SlowFill(request: SlowFillRequestWithBlock): Event;
    executeV3SlowRelayLeaf(leaf: SlowFillLeaf): Event;
    executeRelayerRefundLeaf(refund: RelayerRefundExecutionWithBlock): Event;
    setEnableRoute(originToken: string, destinationChainId: number, enabled: boolean, overrides?: EventOverrides): Event;
}
export {};
