import { __awaiter, __generator } from "tslib";
import { Contract } from "ethers";
import { getABI } from "./abi";
// Multicall3 Constants:
export var multicall3Addresses = {
    1: "0xcA11bde05977b3631167028862bE2a173976CA11",
    10: "0xcA11bde05977b3631167028862bE2a173976CA11",
    137: "0xcA11bde05977b3631167028862bE2a173976CA11",
    324: "0xF9cda624FBC7e059355ce98a31693d299FACd963",
    8453: "0xcA11bde05977b3631167028862bE2a173976CA11",
    42161: "0xcA11bde05977b3631167028862bE2a173976CA11",
    59144: "0xcA11bde05977b3631167028862bE2a173976CA11",
    534352: "0xcA11bde05977b3631167028862bE2a173976CA11",
    // Testnets
    5: "0xcA11bde05977b3631167028862bE2a173976CA11",
    300: "0xF9cda624FBC7e059355ce98a31693d299FACd963",
    59140: "0xcA11bde05977b3631167028862bE2a173976CA11",
    84531: "0xcA11bde05977b3631167028862bE2a173976CA11",
    84532: "0xcA11bde05977b3631167028862bE2a173976CA11",
    421613: "0xcA11bde05977b3631167028862bE2a173976CA11",
    534351: "0xcA11bde05977b3631167028862bE2a173976CA11",
    11155111: "0xcA11bde05977b3631167028862bE2a173976CA11",
};
export function getMulticall3(chainId, signerOrProvider) {
    return __awaiter(this, void 0, void 0, function () {
        var address, _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    address = multicall3Addresses[chainId];
                    if (!address) {
                        return [2 /*return*/, undefined];
                    }
                    _a = Contract.bind;
                    _b = [void 0, address];
                    return [4 /*yield*/, getABI("Multicall3")];
                case 1: return [2 /*return*/, new (_a.apply(Contract, _b.concat([_c.sent(), signerOrProvider])))()];
            }
        });
    });
}
export function aggregate(multicall3, calls, blockTag) {
    return __awaiter(this, void 0, void 0, function () {
        var inputs, _a, results;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    inputs = calls.map(function (_a) {
                        var contract = _a.contract, method = _a.method, args = _a.args;
                        return ({
                            target: contract.address,
                            callData: contract.interface.encodeFunctionData(method, args),
                        });
                    });
                    return [4 /*yield*/, multicall3.callStatic.aggregate(inputs, { blockTag: blockTag })];
                case 1:
                    _a = _b.sent(), results = _a[1];
                    return [2 /*return*/, results.map(function (result, idx) {
                            var _a = calls[idx], contract = _a.contract, method = _a.method;
                            return contract.interface.decodeFunctionResult(method, result);
                        })];
            }
        });
    });
}
//# sourceMappingURL=Multicall.js.map